@@ -10,6 +10,11 @@
 
 #include <string>
 
+namespace SKELETON
+{
+    class UNDO_BUFFER;
+}
+
 namespace BBSLIST
 {
     class BBSListToolBar;
@@ -41,11 +46,11 @@ namespace BBSLIST
         virtual void close_view( const std::string& url ){}
         virtual void close_all_view( const std::string& url ){}
 
+        // (お気に入りの)アイコン表示切り替え
         virtual void toggle_icon( const std::string& url );
 
         // タブの D&D 処理をしない
-        virtual void slot_drag_begin( int page ){}
-        virtual void slot_drag_end(){}
+        virtual void slot_drag_data_get( Gtk::SelectionData& selection_data, const int page ){}
 
         // タブメニュー表示キャンセル
         virtual void slot_tab_menu( int page, int x, int y ){}
@@ -53,6 +58,9 @@ namespace BBSLIST
     
     BBSLIST::BBSListAdmin* get_admin();
     void delete_admin();
+
+    SKELETON::UNDO_BUFFER* get_undo_buffer_favorite();
+    void delete_undo_buffer_favorite();
 }
 
 #endif
