@@ -13,6 +13,7 @@
 #include "jdlib/confloader.h"
 #include "jdlib/miscutil.h"
 #include "jdlib/miscgtk.h"
+#include "jdlib/jdregex.h"
 
 #include "colorid.h"
 #include "fontid.h"
@@ -53,6 +54,7 @@ std::string get_default_font()
 
 
 ConfigItems::ConfigItems()
+    : m_loaded( false )
 {
     str_color.resize( COLOR_NUM );
     fontname.resize( FONT_NUM );
@@ -81,6 +83,8 @@ const bool ConfigItems::load()
               << "conffile = " << path_conf << " empty = " << cf.empty() << std::endl;
 #endif
 
+    std::string str_tmp;
+
     // 色
     set_colors( cf );
 
@@ -108,17 +112,20 @@ const bool ConfigItems::load()
 
     // 読み込み用プロクシとポート番号
     use_proxy_for2ch = cf.get_option( "use_proxy_for2ch", CONF_USE_PROXY_FOR2CH );
-    proxy_for2ch = cf.get_option( "proxy_for2ch", "" );
+    str_tmp = cf.get_option( "proxy_for2ch", "" );
+    set_proxy_for2ch( str_tmp );
     proxy_port_for2ch = cf.get_option( "proxy_port_for2ch", CONF_PROXY_PORT_FOR2CH );
 
     // 書き込み用プロクシとポート番号
     use_proxy_for2ch_w = cf.get_option( "use_proxy_for2ch_w", CONF_USE_PROXY_FOR2CH_W );
-    proxy_for2ch_w = cf.get_option( "proxy_for2ch_w", "" );
+    str_tmp = cf.get_option( "proxy_for2ch_w", "" );
+    set_proxy_for2ch_w( str_tmp );
     proxy_port_for2ch_w = cf.get_option( "proxy_port_for2ch_w", CONF_PROXY_PORT_FOR2CH_W );
 
     // 2chの外にアクセスするときのプロクシとポート番号
     use_proxy_for_data = cf.get_option( "use_proxy_for_data", CONF_USE_PROXY_FOR_DATA );
-    proxy_for_data = cf.get_option( "proxy_for_data", "" );
+    str_tmp = cf.get_option( "proxy_for_data", "" );
+    set_proxy_for_data( str_tmp );
     proxy_port_for_data = cf.get_option( "proxy_port_for_data", CONF_PROXY_PORT_FOR_DATA );
 
     // 2ch にアクセスするときのエージェント名
@@ -368,7 +375,6 @@ const bool ConfigItems::load()
 
     std::list< std::string > list_tmp;
     std::list< std::string >::iterator it_tmp;
-    std::string str_tmp;
 
     // スレ あぼーん word
     str_tmp = cf.get_option( "abonewordthread", "" );
@@ -406,11 +412,22 @@ const bool ConfigItems::load()
     // 3ペーン時にスレ一覧やスレビューを最大化する
     expand_rpane = cf.get_option( "expand_rpane", CONF_EXPAND_RPANE );
 
+    // 次スレ検索の類似度のしきい値
+    threshold_next = cf.get_option( "threshold_next", CONF_THRESHOLD_NEXT );
+
+    // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
+    replace_favorite_next = cf.get_option( "replace_favorite_next", CONF_REPLACE_FAVORITE_NEXT );
+
+    // スレをお気に入りに追加したときにしおりをセットする
+    bookmark_drop = cf.get_option( "bookmark_drop", CONF_BOOKMARK_DROP );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     migemodict_path = cf.get_option( "migemodict_path", CONF_MIGEMO_PATH );
 #endif
 
+    m_loaded = true;
+
     return ! cf.empty();
 }
 
@@ -425,6 +442,8 @@ void ConfigItems::save()
 
 void ConfigItems::save_impl( const std::string& path )
 {
+    if( ! m_loaded ) return;
+
 #ifdef _DEBUG
     std::cout << "ConfigItems::save_impl path = " << path << std::endl;
 #endif
@@ -461,18 +480,25 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "agent_for2ch", agent_for2ch );
 
+    std::string tmp_proxy;
+    if( proxy_basicauth_for2ch.empty() ) tmp_proxy = proxy_for2ch;
+    else tmp_proxy = proxy_basicauth_for2ch + "@" + proxy_for2ch;
     cf.update( "use_proxy_for2ch", use_proxy_for2ch );
-    cf.update( "proxy_for2ch", proxy_for2ch );
+    cf.update( "proxy_for2ch", tmp_proxy );
     cf.update( "proxy_port_for2ch", proxy_port_for2ch );
 
+    if( proxy_basicauth_for2ch_w.empty() ) tmp_proxy = proxy_for2ch_w;
+    else tmp_proxy = proxy_basicauth_for2ch_w + "@" + proxy_for2ch_w;
     cf.update( "use_proxy_for2ch_w", use_proxy_for2ch_w );
-    cf.update( "proxy_for2ch_w", proxy_for2ch_w );
+    cf.update( "proxy_for2ch_w", tmp_proxy );
     cf.update( "proxy_port_for2ch_w", proxy_port_for2ch_w );
 
     cf.update( "agent_for_data", agent_for_data );
 
+    if( proxy_basicauth_for_data.empty() ) tmp_proxy = proxy_for_data;
+    else tmp_proxy = proxy_basicauth_for_data + "@" + proxy_for_data;
     cf.update( "use_proxy_for_data", use_proxy_for_data );
-    cf.update( "proxy_for_data", proxy_for_data );
+    cf.update( "proxy_for_data", tmp_proxy );
     cf.update( "proxy_port_for_data", proxy_port_for_data );
 
     cf.update( "x_2ch_ua", x_2ch_ua );
@@ -628,6 +654,10 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "expand_sidebar", expand_sidebar );
     cf.update( "expand_rpane", expand_rpane );
 
+    cf.update( "threshold_next", threshold_next );
+    cf.update( "replace_favorite_next", replace_favorite_next );
+    cf.update( "bookmark_drop", bookmark_drop );
+
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
 #endif
@@ -795,3 +825,52 @@ void ConfigItems::reset_colors()
     JDLIB::ConfLoader cf( "", "dummy = dummy" );
     set_colors( cf );
 }
+
+
+//
+// プロクシ設定
+//
+void ConfigItems::set_proxy_for2ch( const std::string& proxy )
+{
+    proxy_for2ch = proxy;
+    proxy_basicauth_for2ch = std::string();
+    if( proxy.empty() ) return;
+
+    // basic認証
+    JDLIB::Regex regex;
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    {
+        proxy_basicauth_for2ch = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        proxy_for2ch = regex.str( 2 );
+    }
+}
+
+void ConfigItems::set_proxy_for2ch_w( const std::string& proxy )
+{
+    proxy_for2ch_w = proxy;
+    proxy_basicauth_for2ch_w = std::string();
+    if( proxy.empty() ) return;
+
+    // basic認証
+    JDLIB::Regex regex;
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    {
+        proxy_basicauth_for2ch_w = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        proxy_for2ch_w = regex.str( 2 );
+    }
+}
+
+void ConfigItems::set_proxy_for_data( const std::string& proxy )
+{
+    proxy_for_data = proxy;
+    proxy_basicauth_for_data = std::string();
+    if( proxy.empty() ) return;
+
+    // basic認証
+    JDLIB::Regex regex;
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    {
+        proxy_basicauth_for_data = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        proxy_for_data = regex.str( 2 );
+    }
+}
