@@ -75,6 +75,9 @@ namespace CONTROL
 
         { "Back", "戻る" },
 
+        { "Undo", ITEM_NAME_UNDO },
+        { "Redo", ITEM_NAME_REDO },
+
         { "Quit", ITEM_NAME_QUIT },
         { "Save", "名前を付けて保存..." },
         { "Delete", ITEM_NAME_DELETE },
@@ -82,7 +85,7 @@ namespace CONTROL
         { "StopLoading", ITEM_NAME_STOPLOADING },
         { "Copy", "コピー" },
         { "SelectAll", "全て選択" },
-        { "AppendFavorite", ITEM_NAME_FAVORITE },
+        { "AppendFavorite", ITEM_NAME_FAVORITE "..." },
         { "Property", "プロパティ..." },
         { "Lock", ITEM_NAME_LOCK },
 
@@ -159,6 +162,8 @@ namespace CONTROL
 
         { "LiveStartStop", ITEM_NAME_LIVE },
 
+        { "SearchNextArticle", "次スレ検索" },
+
         { "PopupWarpButton", "クリックで多重ポップアップモードに移行" },
         { "ReferResButton", "参照レスポップアップ表示" },
         { "BmResButton", "ブックマーク" },
