@@ -18,13 +18,21 @@ namespace DBTREE
         Board2ch( const std::string& root, const std::string& path_board,const std::string& name );
         virtual ~Board2ch();
 
+        // ユーザエージェント
         virtual const std::string& get_agent();
 
+        // 読み込み用プロキシ
         virtual const std::string get_proxy_host();
         virtual const int get_proxy_port();
+        virtual const std::string get_proxy_basicauth();
 
+        // 書き込み用プロキシ
         virtual const std::string get_proxy_host_w();
         virtual const int get_proxy_port_w();
+        virtual const std::string get_proxy_basicauth_w();
+
+        // 書き込み用クッキー
+        virtual const std::string cookie_for_write();
 
         // 新スレ作成用のメッセージ変換
         virtual const std::string create_newarticle_message( const std::string& subject,
