@@ -10,6 +10,28 @@
 
 namespace CORE
 {
+    class ColorTreeColumn : public Gtk::TreeModel::ColumnRecord
+    {
+      public:
+
+        Gtk::TreeModelColumn< Glib::ustring > m_col_name;
+        Gtk::TreeModelColumn< std::string > m_col_color;
+        Gtk::TreeModelColumn< int > m_col_colorid;
+        Gtk::TreeModelColumn< std::string > m_col_default;
+
+        ColorTreeColumn()
+        {
+            add( m_col_name );
+            add( m_col_color );
+            add( m_col_colorid );
+            add( m_col_default );
+        }
+    };
+
+
+    ////////////////////////////////
+
+
     class FontColorPref : public SKELETON::PrefDiag
     {
         // ツールチップ
@@ -19,35 +41,35 @@ namespace CORE
         std::vector< int > m_font_tbl;
         std::vector< std::string > m_tooltips_font;
 
+        Gtk::HBox m_hbox_font;
+        Gtk::VBox m_vbox_font;
         Gtk::EventBox m_event_font;
         Gtk::ComboBoxText m_combo_font;
         Gtk::FontButton m_fontbutton;
+
+        Gtk::HBox m_hbox_checkbutton;
         Gtk::CheckButton m_checkbutton_font;
 
+        Gtk::HBox m_hbox_space_ubar;
         Gtk::Label m_label_space;
         SKELETON::SpinButtonDouble m_spin_space;
-
         Gtk::Label m_label_ubar;
         SKELETON::SpinButtonDouble m_spin_ubar;
 
-        Gtk::HBox m_hbox_space;
-        Gtk::HBox m_hbox_checkbutton;
-        Gtk::HBox m_hbox_ubar;
-        Gtk::HBox m_hbox_font;
-        Gtk::VBox m_vbox_font;
+        Gtk::HBox m_hbox_reset_font;
+        Gtk::Button m_bt_reset_font;
+
         Gtk::Frame m_frame_font;
 
         // 色の設定
-        std::vector< int > m_color_tbl;
-        std::vector< std::string > m_tooltips_color;
-
-        Gtk::EventBox m_event_color;
-        Gtk::ComboBoxText m_combo_color;
-        Gtk::ColorButton m_colorbutton;
-        Gtk::Button m_reset_colorbutton;
-        Gtk::HBox m_hbox_color;
         Gtk::VBox m_vbox_color;
-        Gtk::Frame m_frame_color;
+        Gtk::TreeView m_treeview_color;
+        Glib::RefPtr< Gtk::ListStore > m_liststore_color;
+        CORE::ColorTreeColumn m_columns_color;
+        Gtk::ScrolledWindow m_scrollwin_color;
+        Gtk::HBox m_hbox_reset_color;
+        Gtk::Button m_bt_reset_color;
+        Gtk::Button m_bt_reset_all_colors;
 
       public:
 
@@ -64,15 +86,18 @@ namespace CORE
         void slot_combo_font_changed();
         void slot_fontbutton_on_set();
         void slot_checkbutton_font_toggled();
+        void slot_reset_font();
 
         // 色の設定
-        void set_color_settings( const std::string& name, const int colorid, const std::string& tooltip );
-        void slot_combo_color_changed();
-        void slot_colorbutton_on_set();
+        void set_color_settings( const int colorid, const std::string& name, const std::string& defaultval );
+        void slot_row_activated( const Gtk::TreeModel::Path& path, Gtk::TreeViewColumn* column );
+        void slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it );
         void slot_reset_color();
+        void slot_reset_all_colors();
 
-        // OK,cancel が押された
+        // OK,cancel,apply が押された
         virtual void slot_ok_clicked();
+        virtual void slot_apply_clicked();
         virtual void slot_cancel_clicked();
     };
 }
