@@ -4,6 +4,10 @@
 //#define _DEBUG_CHUNKED
 #include "jddebug.h"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "loader.h"
 #include "miscmsg.h"
 #include "miscutil.h"
@@ -14,6 +18,7 @@
 #include "httpcode.h"
 
 #include <sstream>
+#include <cstring>
 
 #include <errno.h>
 #include <fcntl.h>
@@ -136,7 +141,7 @@ Loader::~Loader()
     std::cout << "Loader::~Loader : url = " << m_data.url << std::endl;
 #endif
 
-    assert( ! m_loading );
+//    assert( ! m_loading );
 }
 
 
@@ -185,6 +190,7 @@ void Loader::wait()
 // cookie_for_write
 // host_proxy ( != empty ならproxy使用 )
 // port_proxy ( == 0 なら 8080 )
+// basicauth_proxy
 // size_buf ( バッファサイズ, k 単位で指定。 == 0 ならデフォルトサイズ(LNG_BUF_MIN)使用)
 // timeout ( タイムアウト秒。==0 ならデフォルト( TIMEOUT )使用  )
 // basicauth
@@ -278,6 +284,20 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
         m_data.port = 443;
     }
 
+    // プロキシ
+    m_data.host_proxy = data_in.host_proxy;
+
+    // 先頭に *tp:// が付いていたら取り除く
+    if( ! m_data.host_proxy.empty() && m_data.host_proxy.find( "tp://" ) != std::string::npos ){
+        const bool protocol = false;
+        m_data.host_proxy = MISC::get_hostname( m_data.host_proxy , protocol );
+    }
+    if( ! m_data.host_proxy.empty() ){
+        m_data.port_proxy = data_in.port_proxy;
+        if( m_data.port_proxy == 0 ) m_data.port_proxy = 8080;
+        m_data.basicauth_proxy = data_in.basicauth_proxy;
+    }
+
     // その他
     m_data.head = data_in.head;
     m_data.str_post = data_in.str_post;
@@ -286,9 +306,6 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     m_data.agent = data_in.agent;
     m_data.referer = data_in.referer;
     m_data.cookie_for_write = data_in.cookie_for_write;
-    m_data.host_proxy = data_in.host_proxy;
-    m_data.port_proxy = data_in.port_proxy;
-    if( m_data.port_proxy == 0 ) m_data.port_proxy = 8080;
     m_data.timeout = MAX( TIMEOUT_MIN, data_in.timeout );
     m_data.ex_field = data_in.ex_field;
     m_data.basicauth = data_in.basicauth;
@@ -306,6 +323,7 @@ bool Loader::run( SKELETON::Loadable* cb, const LOADERDATA& data_in )
     std::cout << "cookie: " << m_data.cookie_for_write << std::endl;
     std::cout << "proxy: " << m_data.host_proxy << std::endl;
     std::cout << "port of proxy: " << m_data.port_proxy << std::endl;
+    std::cout << "proxy basicauth : " << m_data.basicauth_proxy << std::endl;
     std::cout << "buffer size: " << m_lng_buf / 1024 << " kb" << std::endl;
     std::cout << "timeout : " << m_data.timeout << " sec" << std::endl;
     std::cout << "ex_field : " << m_data.ex_field << std::endl;
@@ -365,12 +383,21 @@ void Loader::run_main()
 #endif
 
     // addrinfo 取得
-    if( m_data.host_proxy.empty() ) m_addrinfo = get_addrinfo( m_data.host, m_data.port );
-    else m_addrinfo = get_addrinfo( m_data.host_proxy, m_data.port_proxy );
-    if( ! m_addrinfo ){
-        m_data.code = HTTP_ERR;
-        errmsg = "getaddrinfo failed : " + m_data.url;
-        goto EXIT_LOADING;
+    if( m_data.host_proxy.empty() ){
+        m_addrinfo = get_addrinfo( m_data.host, m_data.port );
+        if( ! m_addrinfo ){
+            m_data.code = HTTP_ERR;
+            errmsg = "getaddrinfo failed : " + m_data.url;
+            goto EXIT_LOADING;
+        }
+    }
+    else{
+        m_addrinfo = get_addrinfo( m_data.host_proxy, m_data.port_proxy );
+        if( ! m_addrinfo ){
+            m_data.code = HTTP_ERR;
+            errmsg = "getaddrinfo failed : " + m_data.host_proxy;
+            goto EXIT_LOADING;
+        }
     }
 
     // ソケット作成
@@ -467,7 +494,14 @@ void Loader::run_main()
             }
 
             // SEND 又は POST
+#ifndef NO_MSG_NOSIGNAL
             ssize_t tmpsize = send( soc, msg_send.data(), send_size , MSG_NOSIGNAL );
+#else
+            // SolarisにはMSG_NOSIGNALが無いのでSIGPIPEをIGNOREする
+            signal( SIGPIPE , SIG_IGN ); /* シグナルを無視する */
+            ssize_t tmpsize = send( soc, msg_send.data(), send_size,0);
+            signal(SIGPIPE,SIG_DFL); /* 念のため戻す */
+#endif            
             if( tmpsize == 0
                 || ( tmpsize < 0 && !( errno == EWOULDBLOCK || errno == EINTR ) ) ){
 
@@ -548,10 +582,29 @@ void Loader::run_main()
             }
 
             if( tmpsize == 0 ) break;
-            if( tmpsize > 0 ) read_size += tmpsize;
+            if( tmpsize > 0 ){
+
+                read_size += tmpsize;
+
+                // ヘッダ取得
+                if( receiving_header ){
+
+                    const int ret = receive_header( m_buf, read_size );
+                    if( ret == HTTP_ERR ){
+
+                        m_data.code = HTTP_ERR;
+                        errmsg = "invalid header : " + m_data.url;
+                        goto EXIT_LOADING;
+                    }
+                    else if( ret == HTTP_OK ) receiving_header = false;
+                }
+
+                if( m_data.length && m_data.length <= m_data.length_current + read_size ) break;
+            }
+
         }
 
-        m_buf[ read_size + 1 ] = '\0';
+        m_buf[ read_size ] = '\0';
 
         // 停止指定
         if( m_stop ) break;
@@ -559,27 +612,22 @@ void Loader::run_main()
         // サーバ側がcloseした
         if( read_size == 0 ){
 
-            // ヘッダを取得する前にcloseした
+            // ヘッダを取得する前にcloseしたらエラー
             if( receiving_header && m_data.size_data == 0 ){
                 m_data.code = HTTP_ERR;         
                 errmsg = "no data";
                 goto EXIT_LOADING;
             }
 
+            // コード304等の場合は終了
             break;
         }
 
-        // ヘッダ取得
+        // ヘッダ取得失敗
         if( receiving_header ){
-
-            if( ! receive_header( m_buf, read_size ) ){
-
-                m_data.code = HTTP_ERR;
-                errmsg = "invalid header : " + m_data.url;
-                goto EXIT_LOADING;
-            }
-            receiving_header = false;
-            if( ! read_size ) continue;
+            m_data.code = HTTP_ERR;         
+            errmsg = "no http header";
+            goto EXIT_LOADING;
         }
 
         m_data.length_current += read_size;
@@ -612,6 +660,8 @@ void Loader::run_main()
             errmsg = "unzip() failed : " + m_data.url;
             goto EXIT_LOADING;
         }
+
+        if( m_data.length && m_data.length <= m_data.length_current ) break;
         
     } while( !m_stop );
 
@@ -671,7 +721,7 @@ EXIT_LOADING:
 
 #ifdef _DEBUG
     std::cout << "Loader::run_main : finish loading : " << m_data.url << std::endl;;
-    std::cout << "read size : " << m_data.length_current << std::endl;;    
+    std::cout << "read size : " << m_data.length_current << " / " << m_data.length << std::endl;;    
     std::cout << "data size : " << m_data.size_data << std::endl;;
     std::cout << "code : " << m_data.code << std::endl << std::endl;
 #endif    
@@ -743,6 +793,9 @@ std::string Loader::create_msg_send()
     // basic認証
     if( ! m_data.basicauth.empty() ) msg << "Authorization: Basic " << MISC::base64( m_data.basicauth ) << "\r\n";
 
+    // proxy basic認証
+    if( use_proxy && ! m_data.basicauth_proxy.empty() ) msg << "Proxy-Authorization: Basic " << MISC::base64( m_data.basicauth_proxy ) << "\r\n";
+
     if( ! m_data.cookie_for_write.empty() ) msg << "Cookie: " << m_data.cookie_for_write << "\r\n";
 
     if( ! m_data.modified.empty() ) msg << "If-Modified-Since: " << m_data.modified << "\r\n";
@@ -779,7 +832,7 @@ std::string Loader::create_msg_send()
 //
 // サーバから送られてきた生データからヘッダ取得
 //
-// 処理を簡単にするためにヘッダはバッファ内にすべてあると仮定(バッファ超えたらエラー)
+// 戻り値 : 成功 HTTP_OK、失敗 HTTP_ERR、未処理 HTTP_INIT
 //
 // 入力
 // buf : 生データ
@@ -789,34 +842,33 @@ std::string Loader::create_msg_send()
 // buf : ヘッダが取り除かれたデータ
 // readsize: 出力データサイズ
 //
-bool Loader::receive_header( char* buf, size_t& read_size )
+const int Loader::receive_header( char* buf, size_t& read_size )
 {
+#ifdef _DEBUG
+    std::cout << "Loader::receive_header : read_size = " << read_size << std::endl;
+#endif
+
     buf[ read_size ] = '\0';
     m_data.str_header = buf;
-
     size_t lng_header = m_data.str_header.find( "\r\n\r\n" );
-    if( lng_header == std::string::npos ) lng_header = m_data.str_header.find( "\n\n" );
-    if( lng_header == std::string::npos ){
-        MISC::ERRMSG( "could not find HTML header" );
-#ifdef _DEBUG
-        std::cout << "Loader::receive_header : read_size = " << read_size << std::endl;
-        std::cout << m_data.str_header << std::endl;
-#endif
-        return false;
+    if( lng_header != std::string::npos ) lng_header += 4;
+    else{
+
+        lng_header = m_data.str_header.find( "\n\n" );
+        if( lng_header != std::string::npos ) lng_header +=2;
+        else return HTTP_INIT;
     }
         
-    lng_header += 2;
     m_data.str_header.resize( lng_header ); 
 
 #ifdef _DEBUG    
-    std::cout << "\nheader : " << lng_header << " byte\n";
+    std::cout << "header : size = " << lng_header << " byte\n";
     std::cout << m_data.str_header << std::endl;
 #endif
 
-    if( ! analyze_header() ) return false;
+    if( ! analyze_header() ) return HTTP_ERR;
                 
     // 残りのデータを前に移動
-    lng_header += 2;
     read_size -= lng_header;
     if( read_size ){
 
@@ -824,7 +876,7 @@ bool Loader::receive_header( char* buf, size_t& read_size )
         buf[ read_size ] = '\0';
     }
 
-    return true;
+    return HTTP_OK;
 }
 
 
@@ -1320,11 +1372,12 @@ bool Loader::wait_recv_send( int fd, bool recv )
             MISC::ERRMSG( "select failed" );
             break;
         }
+
         if( errno != EINTR && FD_ISSET( fd, &fdset ) ) return true;
         if( m_stop ) break;
         if( ++count >= m_data.timeout ) break;
 #ifdef _DEBUG
-        std::cout << "Loader::wait_recv_send ret = " << ret << " timeout = " << count << std::endl;
+        std::cout << "Loader::wait_recv_send ret = " << ret << " errno = " << errno << " timeout = " << count << std::endl;
 #endif
     }
     
