@@ -24,12 +24,14 @@ namespace CORE
         VIEW_SELECTLIST,
 
         VIEW_BOARDVIEW,
+        VIEW_BOARDNEXT,
 
         VIEW_ARTICLEVIEW,
         VIEW_ARTICLERES,
         VIEW_ARTICLENAME,
         VIEW_ARTICLEID,
         VIEW_ARTICLEBM,
+        VIEW_ARTICLEPOST,
         VIEW_ARTICLEURL,
         VIEW_ARTICLEREFER,
         VIEW_ARTICLEDRAWOUT,
@@ -38,6 +40,7 @@ namespace CORE
         VIEW_ARTICLESEARCHLOG,
         VIEW_ARTICLESEARCHALLLOG,
         VIEW_ARTICLESEARCHTITLE,
+        VIEW_ARTICLEPOSTLOG,
 
         VIEW_ARTICLEPOPUPHTML,
         VIEW_ARTICLEPOPUPRES,
@@ -64,7 +67,7 @@ namespace CORE
         std::string arg4;
     };
     
-    SKELETON::View* ViewFactory( int type, const std::string& url, VIEWFACTORY_ARGS args = VIEWFACTORY_ARGS() );
+    SKELETON::View* ViewFactory( int type, const std::string& url, VIEWFACTORY_ARGS view_args = VIEWFACTORY_ARGS() );
 }
 
 #endif
